import NetToolBase from "../netTool/base"
import type { Gitlab } from "../types"

class GitlabBaseService extends NetToolBase {
  public project_id: number = 0;
  public merge_request_iid: number = 0;

  constructor(baseUrl: string, authKey: string, requestId: string) {
    super({
      prefix: baseUrl,
      requestId,
      headers: { "PRIVATE-TOKEN": authKey },
    })
  }

  /**
   * 包装一个 GitLab 请求函数，处理错误并返回默认值。
   * @template T
   * @param {() => Promise<T>} func - 要执行的请求函数。
   * @param {any} default_value - 请求失败时返回的默认值。
   * @returns {Promise<T>} 一个解析为请求结果或默认值的 promise。
   */
  protected async errorWarp<T = any>(
    func: () => Promise<T>,
    default_value: any
  ): Promise<T> {
    try {
      let response = {} as T & Gitlab.Error
      response = (await func()) as T & Gitlab.Error
      if (response.message === "404 Project Not Found") return default_value
      return response
    } catch {
      return default_value
    }
  }
}

export default GitlabBaseService
